==> export-cis-2015.2.12-sources.jar: com/xebialabs/xlplatform/extensions/exportcis/CisExportSupport.scala <==
package com.xebialabs.xlplatform.extensions.exportcis

import com.xebialabs.deployit.engine.api.ServiceHolder
import com.xebialabs.deployit.jcr.JcrTemplateHolder
import com.xebialabs.deployit.plugin.api.flow.{ExecutionContext, Step, StepExitCode}
import com.xebialabs.deployit.repository.NodeReaderContext
import com.xebialabs.deployit.repository.RepositoryServiceHolder._
import com.xebialabs.xlplatform.endpoints.{AuthenticatedData, ServicesSupport}
import com.xebialabs.xlplatform.extensions.exportcis.archive.RepositoryExporter
import grizzled.slf4j.Logging
import org.joda.time.DateTime
import org.joda.time.format.DateTimeFormat

import scala.collection.JavaConversions._
import scala.util.{Failure, Success}
import scalax.file.defaultfs.DefaultPath


trait CisExportSupport extends ServicesSupport with Logging {

  def export(rootCiId: String, destinationPath: DefaultPath)(implicit auth: AuthenticatedData): String = {

    destinationPath.createDirectory(failIfExists = false)
    val date = DateTimeFormat.forPattern("yyyy-MM-dd_HH-mm-ss_sss").print(DateTime.now)
    val exportFileName = s"${rootCiId.split("/").lastOption.getOrElse("Root")}_$date.zip"
    val exportFile = destinationPath / exportFileName
    val version = ServiceHolder.getServerService.getInfo.getVersion

    taskCreationService.createWithStepBlock(auth.toAuthentication,
      s"Export CI tree starting from '$rootCiId' into '${destinationPath.path}'",
      List(ExportStep(rootCiId, exportFile, auth.username, version)),
      Map("exportedFile" -> exportFile.path))
  }

}

case class ExportStep(rootCiId: String, toFile: DefaultPath, username: String,
                      version: String) extends Step with Logging {

  override def execute(ctx: ExecutionContext): StepExitCode = {
    JcrTemplateHolder.get.login()
    NodeReaderContext.get.hold()
    val exporter = new RepositoryExporter(getRepositoryService, ctx)
    val code = exporter.export(List(rootCiId), toFile, username, version) match {
      case Success(_) => StepExitCode.SUCCESS
      case Failure(e) =>
        logger.error(s"Failed to export $rootCiId to $toFile", e)
        StepExitCode.FAIL
    }

    JcrTemplateHolder.get.logout()
    NodeReaderContext.get.release()

    code
  }

  override def getDescription: String = "Export configuration items into a ZIP file"
  override def getOrder: Int = Step.DEFAULT_ORDER
}

==> export-cis-2016.2.0-sources.jar: com/xebialabs/xlplatform/extensions/exportcis/CisExportSupport.scala <==
package com.xebialabs.xlplatform.extensions.exportcis

import com.xebialabs.deployit.engine.api.ServiceHolder
import com.xebialabs.deployit.jcr.JcrTemplateHolder
import com.xebialabs.deployit.plugin.api.flow.{ExecutionContext, Step, StepExitCode}
import com.xebialabs.deployit.repository.{WorkDirContext, NodeReaderContext}
import com.xebialabs.deployit.repository.RepositoryServiceHolder._
import com.xebialabs.xlplatform.endpoints.{AuthenticatedData, ServicesSupport}
import com.xebialabs.xlplatform.extensions.exportcis.archive.RepositoryExporter
import grizzled.slf4j.Logging
import org.joda.time.DateTime
import org.joda.time.format.DateTimeFormat

import scala.collection.JavaConversions._
import scala.util.{Failure, Success}
import scalax.file.defaultfs.DefaultPath


trait CisExportSupport extends ServicesSupport with Logging {

  def export(rootCiId: String, destinationPath: DefaultPath)(implicit auth: AuthenticatedData): String = {
    WorkDirContext.initWorkdir("export")
    try {
      destinationPath.createDirectory(failIfExists = false)
      val date = DateTimeFormat.forPattern("yyyy-MM-dd_HH-mm-ss_sss").print(DateTime.now)
      val exportFileName = s"${rootCiId.split("/").lastOption.getOrElse("Root")}_$date.zip"
      val exportFile = destinationPath / exportFileName
      val version = ServiceHolder.getServerService.getInfo.getVersion

      taskCreationService.createWithStepBlock(auth.toAuthentication,
        s"Export CI tree starting from '$rootCiId' into '${destinationPath.path}'",
        List(ExportStep(rootCiId, exportFile, auth.username, version)),
        Map("exportedFile" -> exportFile.path))
    } finally {
      WorkDirContext.clear()
    }
  }

}

case class ExportStep(rootCiId: String, toFile: DefaultPath, username: String,
                      version: String) extends Step with Logging {

  override def execute(ctx: ExecutionContext): StepExitCode = {
    JcrTemplateHolder.get.login()
    NodeReaderContext.get.hold()
    val exporter = new RepositoryExporter(getRepositoryService, ctx)
    val code = exporter.export(List(rootCiId), toFile, username, version) match {
      case Success(_) => StepExitCode.SUCCESS
      case Failure(e) =>
        logger.error(s"Failed to export $rootCiId to $toFile", e)
        StepExitCode.FAIL
    }

    JcrTemplateHolder.get.logout()
    NodeReaderContext.get.release()

    code
  }

  override def getDescription: String = "Export configuration items into a ZIP file"
  override def getOrder: Int = Step.DEFAULT_ORDER
}
